@@ -1,9 +1,7 @@
 package Protocol::XMPP::Element::Bind;
-BEGIN {
-  $Protocol::XMPP::Element::Bind::VERSION = '0.005';
-}
+$Protocol::XMPP::Element::Bind::VERSION = '0.006';
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 use parent qw(Protocol::XMPP::ElementBase);
 
 =head1 NAME
@@ -12,7 +10,7 @@ Protocol::XMPP::Bind - register ability to deal with a specific feature
 
 =head1 VERSION
 
-version 0.005
+Version 0.006
 
 =head1 SYNOPSIS
 
@@ -31,7 +29,18 @@ sub end_element {
 	return unless $self->parent->isa('Protocol::XMPP::Element::Features');
 
 	$self->debug("Had bind request");
-	$self->write_xml(['iq', 'type' => 'set', id => $self->next_id, _content => [[ 'bind', '_ns' => 'xmpp-bind' ]] ]);
+	$self->parent->push_pending(my $f = $self->stream->new_future);
+	my $id = $self->next_id;
+	$self->stream->pending_iq($id => $f);
+	$self->write_xml([
+		'iq',
+		'type' => 'set',
+		id => $id,
+		_content => [[
+			'bind',
+			'_ns' => 'xmpp-bind'
+		]]
+	]);
 }
 
 1;
@@ -44,4 +53,4 @@ Tom Molesworth <cpan@entitymodel.com>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2010-2011. Licensed under the same terms as Perl itself.
\ No newline at end of file
+Copyright Tom Molesworth 2010-2014. Licensed under the same terms as Perl itself.
