@@ -1,9 +1,7 @@
 package Protocol::XMPP::Element::Features;
-BEGIN {
-  $Protocol::XMPP::Element::Features::VERSION = '0.005';
-}
+$Protocol::XMPP::Element::Features::VERSION = '0.006';
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 use parent qw(Protocol::XMPP::ElementBase);
 
 =head1 NAME
@@ -12,7 +10,7 @@ Protocol::XMPP::Features - broker for setting up internal state and triggering r
 
 =head1 VERSION
 
-version 0.005
+Version 0.006
 
 =head1 SYNOPSIS
 
@@ -32,8 +30,21 @@ sub end_element {
 	$self->stream->{features} = $self; # strong ref, parent will remove when no longer needed
 	$self->stream->dispatch_event('features');
 	return if $self->stream->{tls_pending};
-	return $self->stream->dispatch_event('login') if $self->is_authorised;
-	$self->stream->dispatch_event('login_ready');
+
+	$self->{waiting_futures} = Future->wait_all(
+		@{$self->{pending_futures}}
+	)->on_ready(sub {
+		delete $self->{waiting_futures};
+		$self->stream->features_complete->done;
+		return $self->stream->dispatch_event('login') if $self->is_authorised;
+		$self->stream->dispatch_event('login_ready');
+	});
+}
+
+sub push_pending {
+	my $self = shift;
+	push @{$self->{pending_futures}}, @_;
+	$self
 }
 
 =head1 C<_sasl_mechanism_list>
@@ -57,4 +68,4 @@ Tom Molesworth <cpan@entitymodel.com>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2010-2011. Licensed under the same terms as Perl itself.
\ No newline at end of file
+Copyright Tom Molesworth 2010-2014. Licensed under the same terms as Perl itself.
