@@ -1,9 +1,7 @@
 package Protocol::XMPP::Element::JID;
-BEGIN {
-  $Protocol::XMPP::Element::JID::VERSION = '0.005';
-}
+$Protocol::XMPP::Element::JID::VERSION = '0.006';
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 use parent qw(Protocol::XMPP::TextElement);
 
 =head1 NAME
@@ -12,7 +10,7 @@ use parent qw(Protocol::XMPP::TextElement);
 
 =head1 VERSION
 
-version 0.005
+Version 0.006
 
 =head1 DESCRIPTION
 
@@ -38,4 +36,4 @@ Tom Molesworth <cpan@entitymodel.com>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2010-2011. Licensed under the same terms as Perl itself.
\ No newline at end of file
+Copyright Tom Molesworth 2010-2014. Licensed under the same terms as Perl itself.
