@@ -1,9 +1,7 @@
 package Protocol::XMPP::Element::Mechanism;
-BEGIN {
-  $Protocol::XMPP::Element::Mechanism::VERSION = '0.005';
-}
+$Protocol::XMPP::Element::Mechanism::VERSION = '0.006';
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 use parent qw(Protocol::XMPP::TextElement);
 
 =head1 NAME
@@ -12,7 +10,7 @@ Protocol::XMPP::Mechanism - information on available auth mechanisms
 
 =head1 VERSION
 
-version 0.005
+Version 0.006
 
 =head1 SYNOPSIS
 
@@ -66,4 +64,4 @@ Tom Molesworth <cpan@entitymodel.com>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2010-2011. Licensed under the same terms as Perl itself.
\ No newline at end of file
+Copyright Tom Molesworth 2010-2014. Licensed under the same terms as Perl itself.
