@@ -1,9 +1,7 @@
 package Protocol::XMPP::Element::Presence;
-BEGIN {
-  $Protocol::XMPP::Element::Presence::VERSION = '0.005';
-}
+$Protocol::XMPP::Element::Presence::VERSION = '0.006';
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 use parent qw(Protocol::XMPP::ElementBase);
 
 use Protocol::XMPP::Contact;
@@ -14,7 +12,7 @@ Protocol::XMPP::Success - indicate success for an operation
 
 =head1 VERSION
 
-version 0.005
+Version 0.006
 
 =head1 SYNOPSIS
 
@@ -45,4 +43,4 @@ Tom Molesworth <cpan@entitymodel.com>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2010-2011. Licensed under the same terms as Perl itself.
\ No newline at end of file
+Copyright Tom Molesworth 2010-2014. Licensed under the same terms as Perl itself.
