@@ -1,9 +1,7 @@
 package Protocol::XMPP::Element::Success;
-BEGIN {
-  $Protocol::XMPP::Element::Success::VERSION = '0.005';
-}
+$Protocol::XMPP::Element::Success::VERSION = '0.006';
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 use parent qw(Protocol::XMPP::ElementBase);
 
 =head1 NAME
@@ -12,7 +10,7 @@ Protocol::XMPP::Success - indicate success for an operation
 
 =head1 VERSION
 
-version 0.005
+Version 0.006
 
 =head1 SYNOPSIS
 
@@ -25,6 +23,10 @@ version 0.005
 sub end_element {
 	my $self = shift;
 	$self->debug("Successful response");
+	# On successful authorisation, we need to start a new stream (without closing
+	# the original one) so that we can go through stream header negotiation again:
+	# authorisation may have enabled additional features that were not advertised
+	# previously.
 	$self->stream->reset;
 	$self->write_text(@{$self->stream->preamble});
 	$self->is_authorised(1);
@@ -40,4 +42,4 @@ Tom Molesworth <cpan@entitymodel.com>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2010-2011. Licensed under the same terms as Perl itself.
\ No newline at end of file
+Copyright Tom Molesworth 2010-2014. Licensed under the same terms as Perl itself.
