@@ -1,9 +1,7 @@
 package Protocol::XMPP::Message;
-BEGIN {
-  $Protocol::XMPP::Message::VERSION = '0.005';
-}
+$Protocol::XMPP::Message::VERSION = '0.006';
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 use parent qw(Protocol::XMPP::Base);
 
 =head1 NAME
@@ -12,7 +10,7 @@ Protocol::XMPP::Feature - register ability to deal with a specific feature
 
 =head1 VERSION
 
-version 0.005
+Version 0.006
 
 =head1 SYNOPSIS
 
@@ -22,7 +20,7 @@ version 0.005
 
 =cut
 
-sub from { shift->{from} || '' }
+sub from { my $self = shift; $self->{from} // $self->stream->jid }
 sub to { shift->{to} || '' }
 sub subject { shift->{subject} || '' }
 sub body { shift->{body} || '' }
@@ -38,7 +36,15 @@ sub reply {
 sub send {
 	my $self = shift;
 	my %args = @_;
-	$self->write_xml(['message', 'from' => $self->from, 'to' => $self->to, type => $self->type, _content => [[ 'body', _content => $self->body ]]]);
+	$self->write_xml([
+		'message',
+		'to' => $self->to,
+		type => $self->type,
+		_content => [[
+			'body',
+			_content => $self->body
+		]]
+	]);
 }
 
 1;
@@ -51,4 +57,4 @@ Tom Molesworth <cpan@entitymodel.com>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2010-2011. Licensed under the same terms as Perl itself.
\ No newline at end of file
+Copyright Tom Molesworth 2010-2014. Licensed under the same terms as Perl itself.
